@@ -1,4 +1,3 @@
-// use crate::song::Song;
 use crate::{
     config::get_app_config_path,
     song::Song,
@@ -191,7 +190,39 @@ impl Model {
 
         assert!(self.app.active(&Id::Library).is_ok());
     }
+
+    fn playlist_filetype_supported(current_node: &str) -> bool {
+        let p = Path::new(current_node);
+
+        #[cfg(any(feature = "mpv", feature = "gst"))]
+        if let Some(ext) = p.extension() {
+            if ext == "opus" {
+                return true;
+            }
+            if ext == "aiff" {
+                return true;
+            }
+            if ext == "webm" {
+                return true;
+            }
+        }
+
+        match p.extension() {
+            Some(ext) if ext == "mp3" => true,
+            // Some(ext) if ext == "aiff" => true,
+            Some(ext) if ext == "flac" => true,
+            Some(ext) if ext == "m4a" => true,
+            // Some(ext) if ext == "opus" => true,
+            Some(ext) if ext == "ogg" => true,
+            Some(ext) if ext == "wav" => true,
+            // Some(ext) if ext == "webm" => true,
+            Some(_) | None => false,
+        }
+    }
     fn playlist_add_item(&mut self, current_node: &str, add_playlist_front: bool) -> Result<()> {
+        if !Self::playlist_filetype_supported(current_node) {
+            return Ok(());
+        }
         match Song::read_from_path(current_node) {
             Ok(item) => {
                 if add_playlist_front {
@@ -210,6 +241,9 @@ impl Model {
         let mut index = 0;
         for s in &new_items {
             if self.config.add_playlist_front {
+                if !Self::playlist_filetype_supported(s) {
+                    continue;
+                }
                 match Song::read_from_path(s) {
                     Ok(item) => {
                         self.playlist_items.insert(index, item);
@@ -381,7 +415,7 @@ impl Model {
             "last"
         };
         let title = format!(
-            "\u{2500} Playlist \u{2500}\u{2500}\u{2524} Total {} tracks | {} | Loop: {} | Add:{} \u{251c}\u{2500}",
+            "\u{2500} Playlist \u{2500}\u{2500}\u{2524} Total {} tracks | {} | Loop: {} | Add: {} \u{251c}\u{2500}",
             self.playlist_items.len(),
             Song::duration_formatted_short(&duration),
             self.config.loop_mode.display(self.config.playlist_display_symbol),
