@@ -1,13 +1,11 @@
-// use crate::song::Song;
 use crate::player::GeneralP;
 use crate::song::Song;
 use crate::ui::{Id, Model, Msg, Status};
 
+use crate::ui::components::StyleColorSymbol;
 use if_chain::if_chain;
 use std::time::Duration;
 use tui_realm_stdlib::ProgressBar;
-// use tuirealm::command::CmdResult;
-use crate::ui::components::StyleColorSymbol;
 use tuirealm::event::NoUserEvent;
 use tuirealm::props::{Alignment, BorderType, Borders, Color, PropPayload, PropValue};
 use tuirealm::{AttrValue, Attribute, Component, Event, MockComponent};
@@ -94,15 +92,17 @@ impl Model {
                 return;
             }
 
-            // if time_pos >= duration {
-            //     self.status = Some(Status::Stopped);
-            //     return;
-            // }
-            // if time_pos > self.time_pos && time_pos - self.time_pos < 1 {
-            //     return;
-            // }
+            if let Some(Status::Paused) = self.status {
+                if let Some(t) = std::time::Instant::now()
+                    .checked_sub(std::time::Duration::from_secs(time_pos.try_into().unwrap()))
+                {
+                    self.time_pos_elapsed = t;
+                }
+                return;
+            }
 
             self.time_pos = time_pos;
+
             if self.time_pos_elapsed.elapsed().as_secs() > duration as u64 {
                 self.status = Some(Status::Stopped);
                 return;
